@@ -5,8 +5,9 @@ import shutil
 import subprocess
 import sys
 from pathlib import Path
-from typing import Any, Dict, Optional, Sequence
+from typing import Any, Dict, Optional, Sequence, Union
 
+import httpcore
 import httpx
 import yaml
 from jinja2 import Environment, PackageLoader
@@ -17,7 +18,7 @@ from .parser import GeneratorData, import_string_from_reference
 from .parser.errors import GeneratorError
 
 if sys.version_info.minor == 7:  # version did not exist in 3.7, need to use a backport
-    from importlib_metadata import version  # type: ignore
+    from importlib_metadata import version
 else:
     from importlib.metadata import version  # type: ignore
 
@@ -25,21 +26,14 @@ else:
 __version__ = version(__package__)
 
 
-def _get_project_for_url_or_path(url: Optional[str], path: Optional[Path]) -> _Project:
+def _get_project_for_url_or_path(url: Optional[str], path: Optional[Path]) -> Union[Project, GeneratorError]:
     data_dict = _get_document(url=url, path=path)
+    if isinstance(data_dict, GeneratorError):
+        return data_dict
     openapi = GeneratorData.from_dict(data_dict)
-    return _Project(openapi=openapi)
-
-
-def load_config(*, path: Path) -> None:
-    """ Loads config from provided Path """
-    config_data = yaml.safe_load(path.read_text())
-
-    if "class_overrides" in config_data:
-        from .parser import reference
-
-        for class_name, class_data in config_data["class_overrides"].items():
-            reference.class_overrides[class_name] = reference.Reference(**class_data)
+    if isinstance(openapi, GeneratorError):
+        return openapi
+    return Project(openapi=openapi)
 
 
 def create_new_client(*, url: Optional[str], path: Optional[Path]) -> Sequence[GeneratorError]:
@@ -50,6 +44,8 @@ def create_new_client(*, url: Optional[str], path: Optional[Path]) -> Sequence[G
          A list containing any errors encountered when generating.
     """
     project = _get_project_for_url_or_path(url=url, path=path)
+    if isinstance(project, GeneratorError):
+        return [project]
     return project.build()
 
 
@@ -61,36 +57,47 @@ def update_existing_client(*, url: Optional[str], path: Optional[Path]) -> Seque
          A list containing any errors encountered when generating.
     """
     project = _get_project_for_url_or_path(url=url, path=path)
+    if isinstance(project, GeneratorError):
+        return [project]
     return project.update()
 
 
-def _get_document(*, url: Optional[str], path: Optional[Path]) -> Dict[str, Any]:
+def _get_document(*, url: Optional[str], path: Optional[Path]) -> Union[Dict[str, Any], GeneratorError]:
     yaml_bytes: bytes
     if url is not None and path is not None:
-        raise ValueError("Provide URL or Path, not both.")
+        return GeneratorError(header="Provide URL or Path, not both.")
     if url is not None:
-        response = httpx.get(url)
-        yaml_bytes = response.content
+        try:
+            response = httpx.get(url)
+            yaml_bytes = response.content
+        except (httpx.HTTPError, httpcore.NetworkError):
+            return GeneratorError(header="Could not get OpenAPI document from provided URL")
     elif path is not None:
         yaml_bytes = path.read_bytes()
     else:
-        raise ValueError("No URL or Path provided")
-    return yaml.safe_load(yaml_bytes)
+        return GeneratorError(header="No URL or Path provided")
+    try:
+        return yaml.safe_load(yaml_bytes)
+    except yaml.YAMLError:
+        return GeneratorError(header="Invalid YAML from provided source")
 
 
-class _Project:
+class Project:
     TEMPLATE_FILTERS = {"snakecase": utils.snake_case}
+    project_name_override: Optional[str] = None
+    package_name_override: Optional[str] = None
 
     def __init__(self, *, openapi: GeneratorData) -> None:
         self.openapi: GeneratorData = openapi
         self.env: Environment = Environment(loader=PackageLoader(__package__), trim_blocks=True, lstrip_blocks=True)
 
-        self.project_name: str = f"{openapi.title.replace(' ', '-').lower()}-client"
+        self.project_name: str = self.project_name_override or f"{openapi.title.replace(' ', '-').lower()}-client"
         self.project_dir: Path = Path.cwd() / self.project_name
 
-        self.package_name: str = self.project_name.replace("-", "_")
+        self.package_name: str = self.package_name_override or self.project_name.replace("-", "_")
         self.package_dir: Path = self.project_dir / self.package_name
-        self.package_description = f"A client library for accessing {self.openapi.title}"
+        self.package_description: str = f"A client library for accessing {self.openapi.title}"
+        self.version: str = openapi.version
 
         self.env.filters.update(self.TEMPLATE_FILTERS)
 
@@ -152,7 +159,10 @@ class _Project:
         pyproject_path = self.project_dir / "pyproject.toml"
         pyproject_path.write_text(
             pyproject_template.render(
-                project_name=self.project_name, package_name=self.package_name, description=self.package_description
+                project_name=self.project_name,
+                package_name=self.package_name,
+                version=self.version,
+                description=self.package_description,
             )
         )
 
